import setuptools
setuptools.setup(
    name='dl2',
    version='0.21.816',
    author='Wenxin Chen',
    author_email='minecraft_cwx@163.com',
    description='凋零工作室二代库，拥有数学、画图拓展、生成HTML文件等模块，在一代的基础上更新了不少',
    ong_descripition_content_type="text/markdown",
    url='https://github.com/',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)